@@ -210,13 +210,20 @@ class Table(metaclass=MetaTable):
                          isinstance(value, tuple) or
                          isinstance(value, dict)) and \
                         ('from' in value or
-                         'to' in value):
+                         'to' in value or
+                         'in' in value):
                         if 'from' in value:
                             values.append(cls.value(field, value['from']))
                             fields.append(cls.name+'."'+column+"\">=%s")
                         if 'to' in value:
                             values.append(cls.value(field, value['to']))
                             fields.append(cls.name+'."'+column+"\"<=%s")
+                        if 'in' in value and (isinstance(value['in'], list) or isinstance(value['in'], tuple)) and len(value['in']):
+                            for item in value['in']:
+                                log.info(color.cyan('%s'), item)
+                                values.append(cls.value(field, item))
+                            fields.append(cls.name+'."'+column+"\" IN ("+','.join(['%s'] * len(value['in']))+")")
+
                     else:
                         if config['type'] != 'json':
                             values.append(cls.value(field, value))
@@ -512,17 +519,17 @@ class Table(metaclass=MetaTable):
         return result
 
     @classmethod
-    def save(cls, id, data, where={}):
-        where = cls.where(where)
+    def save(cls, id, data, filter={}):
+        filter = cls.where(filter)
         update = cls.update(data)
         try:
             db = cls.get_db()
             cursor = db.cursor()
             cursor.execute(*debug(f"""UPDATE {cls}
                                     SET {update.fields()}
-                                    WHERE {cls('id')}=%s AND {where.fields()}
+                                    WHERE {cls('id')}=%s AND {filter.fields()}
                                     RETURNING {cls.select()}""",
-                                update.values(id)+where.values()))
+                                update.values(id)+filter.values()))
             result = cls.create(cursor.fetchone())
         except Exception as error:
             raise error
@@ -594,8 +601,8 @@ class Row:
 
 
 class Result():
-    def __init__(self):
-        self.total = None
+    def __init__(self, total=None):
+        self.total = total
         self.items = []
     def add(self, item):
         self.items.append(item)
